import 'package:flutter/material.dart';

import '../nb_utils.dart';

/// show confirm dialog box
Future showConfirmDialog<bool>(
  context,
  String title, {
  String positiveText = 'Yes',
  String negativeText = 'No',
  Color buttonColor,
}) async {
  return showDialog(
    context: context,
    barrierDismissible: false,
    child: AlertDialog(
      title: Text(title.validate()),
      actions: <Widget>[
        SimpleDialogOption(
          child: Text(negativeText.validate(), style: secondaryTextStyle()),
          onPressed: () {
            finish(context, false);
          },
        ),
        SimpleDialogOption(
          onPressed: () {
            finish(context, true);
          },
          child: Text(positiveText.validate(),
              style: primaryTextStyle(
                  color: buttonColor ?? Theme.of(context).primaryColor)),
        ),
      ],
    ),
  );
}

/// show child widget in dialog
Future<dynamic> showInDialog(
  BuildContext context, {
  Widget title,
  Widget child,
  ShapeBorder shape,
  TextStyle titleTextStyle,
  EdgeInsetsGeometry contentPadding =
      const EdgeInsets.fromLTRB(24.0, 20.0, 24.0, 24.0),
  //bool scrollable = false,
  Color backgroundColor,
  double elevation,
  //EdgeInsets insetPadding = const EdgeInsets.symmetric(horizontal: 16.0, vertical: 16.0),
  List<Widget> actions,
  bool barrierDismissible = true,
}) async {
  return await showDialog(
    context: context,
    barrierDismissible: barrierDismissible,
    child: AlertDialog(
      content: child,
      shape: shape,
      title: title,
      titleTextStyle: titleTextStyle,
      contentPadding: contentPadding,
      //scrollable: scrollable,
      backgroundColor: backgroundColor,
      elevation: elevation,
      //insetPadding: insetPadding,
      actions: actions,
    ),
  );
}

/// Default AppBar
AppBar appBarWidget(
  String title, {
  List<Widget> actions,
  Color color,
  bool center = false,
  Color textColor,
  int textSize = 20,
  bool showBack = true,
  Color shadowColor,
}) {
  return AppBar(
    centerTitle: center,
    title: Text(title,
        style: boldTextStyle(
            color: textColor ?? textPrimaryColorGlobal, size: textSize)),
    actions: actions,
    automaticallyImplyLeading: showBack,
    backgroundColor: color ?? appBarBackgroundColorGlobal,
    leading: showBack
        ? BackButton(color: textColor ?? textPrimaryColorGlobal)
        : null,
    shadowColor: shadowColor,
  );
}

enum SymbolType { Bullet, Numbered, Custom }

/// Add UL to its children
class UL extends StatelessWidget {
  final List<Widget> children;
  final double padding;
  final double spacing;
  final SymbolType symbolType;
  final Color symbolColor;
  final Color textColor;
  final Widget customSymbol;

  UL({
    this.children = const <Widget>[],
    this.padding = 8,
    this.spacing = 8,
    this.symbolType = SymbolType.Bullet,
    this.symbolColor,
    this.textColor,
    this.customSymbol,
  });

  @override
  Widget build(BuildContext context) {
    return Wrap(
      runSpacing: spacing,
      direction: Axis.horizontal,
      children: children
          .asMap()
          .map((i, element) => MapEntry(
                i,
                Row(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    symbolType == SymbolType.Bullet
                        ? Transform.scale(
                            scale: 2.0,
                            child: Text('•',
                                style: TextStyle(
                                    color:
                                        textColor ?? textPrimaryColorGlobal)))
                        : SizedBox(),
                    symbolType == SymbolType.Numbered
                        ? Text('${i + 1}',
                            style: TextStyle(
                                fontSize: 16,
                                color: symbolColor ?? textPrimaryColorGlobal))
                        : SizedBox(),
                    (symbolType == SymbolType.Custom && customSymbol != null)
                        ? customSymbol
                        : SizedBox(),
                    SizedBox(width: padding),
                    element.expand(),
                  ],
                ),
              ))
          .values
          .toList(),
    );
  }
}

/// set different layout based on current screen size (mobile, web, desktop)
class Responsive extends StatelessWidget {
  final Widget web;
  final Widget mobile;
  final bool useFullWidth;
  final double width;

  Responsive({this.web, @required this.mobile, this.useFullWidth, this.width});

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (_, constraints) {
        if (constraints.device == DeviceSize.mobile) {
          return mobile;
        } else if (constraints.device == DeviceSize.desktop) {
          /// $desktopBreakpointGlobal checkout this variable to breakout desktop widget
          return Container(
            alignment: Alignment.topCenter,
            child: Container(
              constraints: useFullWidth.validate(value: true)
                  ? null
                  : BoxConstraints(maxWidth: width ?? (context.width() * 0.9)),
              child: web ?? SizedBox(),
            ),
          );
        }
        return mobile ?? web ?? SizedBox();
      },
    );
  }
}
